Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(119)

Unified Diff: ash/common/system/chromeos/network/vpn_list_view.h

Issue 2698473007: Convert path usage in NetworkListViewBase subclasses to use guids. (Closed)
Patch Set: Tweak NetworkPortalNotificationControllerTest to create GUIDs for new NetworkStates. Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/common/system/chromeos/network/vpn_list_view.h
diff --git a/ash/common/system/chromeos/network/vpn_list_view.h b/ash/common/system/chromeos/network/vpn_list_view.h
index 399709add17ed209327b816445a2358f3955d9a0..6b9c3a8220344dea7b2e41684e33d72c35deacdb 100644
--- a/ash/common/system/chromeos/network/vpn_list_view.h
+++ b/ash/common/system/chromeos/network/vpn_list_view.h
@@ -50,8 +50,7 @@ class VPNListView : public NetworkListViewBase,
// NetworkListViewBase:
void Update() override;
- bool IsNetworkEntry(views::View* view,
- std::string* service_path) const override;
+ bool IsNetworkEntry(views::View* view, std::string* guid) const override;
// VpnList::Observer:
void OnVPNProvidersChanged() override;
@@ -78,9 +77,8 @@ class VPNListView : public NetworkListViewBase,
// A mapping from each VPN provider's list entry to the provider.
std::map<const views::View* const, VPNProvider> provider_view_map_;
- // A mapping from each network's list entry to the network's service path.
- std::map<const views::View* const, std::string>
- network_view_service_path_map_;
+ // A mapping from each network's list entry to the network's guid.
+ std::map<const views::View* const, std::string> network_view_guid_map_;
// Whether the list is currently empty (i.e., the next entry added will become
// the topmost entry).
« no previous file with comments | « ash/common/system/chromeos/network/tray_network.cc ('k') | ash/common/system/chromeos/network/vpn_list_view.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698